@@ -10,14 +10,21 @@ defined in official github repo
 https://github.com/obsproject/obs-websocket/blob/master/docs/generated/protocol.md#Requests
 """
 
+logger = logging.getLogger(__name__)
+
 
 class ReqClient:
-    logger = logging.getLogger("reqs.reqclient")
-
     def __init__(self, **kwargs):
+        self.logger = logger.getChild(self.__class__.__name__)
         self.base_client = ObsClient(**kwargs)
-        if self.base_client.authenticate():
-            self.logger.info(f"Successfully identified {self} with the server")
+        try:
+            success = self.base_client.authenticate()
+            self.logger.info(
+                f"Successfully identified {self} with the server using RPC version:{success['negotiatedRpcVersion']}"
+            )
+        except OBSSDKError as e:
+            self.logger.error(f"{type(e).__name__}: {e}")
+            raise
 
     def __enter__(self):
         return self
@@ -28,7 +35,7 @@ class ReqClient:
     def __repr__(self):
         return type(
             self
-        ).__name__ + "(host='{host}', port={port}, password='{password}')".format(
+        ).__name__ + "(host='{host}', port={port}, password='{password}', timeout={timeout})".format(
             **self.base_client.__dict__,
         )
 
